@@ -1,8 +1,9 @@
-import json
 from typing import Optional, List
 
+from .basemodel import BaseModel
 
-class RunExecution(object):
+
+class RunExecution(BaseModel):
     def __init__(self,
                  start_time: float,
                  end_time: float,
@@ -17,7 +18,7 @@ class RunExecution(object):
         self.cumulative_duration += result["execution"]["duration"]
 
 
-class RunStats(object):
+class RunStats(BaseModel):
     def __init__(self) -> None:
         self.passed = 0
         self.failed = 0
@@ -41,7 +42,7 @@ class RunStats(object):
             self.muted += 1
 
 
-class Run(object):
+class Run(BaseModel):
     def __init__(self,
                  title: str,
                  start_time: float,
@@ -60,9 +61,6 @@ class Run(object):
         self.suites = suites
         self.environment = environment
 
-    def to_json(self) -> str:
-        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=False, indent=4)
-
     def add_result(self, result: dict):
         compact_result = {
             "id": result["id"],
@@ -71,6 +69,7 @@ class Run(object):
             "duration": result["execution"]["duration"],
             "thread": result["execution"]["thread"]
         }
+        self._extract_path_from_relations(result)
         self.results.append(compact_result)
         self.execution.track(result)
         self.stats.track(result)
@@ -79,3 +78,16 @@ class Run(object):
 
     def add_host_data(self, host_data: dict):
         self.host_data = host_data
+
+    def _extract_path_from_relations(self, relations_dict):
+
+        titles = []
+        if "relations" in relations_dict and "suite" in relations_dict["relations"]:
+            if "data" in relations_dict["relations"]["suite"]:
+                data_list = relations_dict["relations"]["suite"]["data"]
+                titles = [item["title"] for item in data_list if "title" in item]
+
+        path = "/".join(titles)
+
+        if path and path not in self.suites:
+            self.suites.append(path)
